@@ -35,9 +35,7 @@ on_main_canvas_key_press_event         (GtkWidget       *widget,
                                         GdkEventKey     *event,
                                         gpointer         user_data)
 {
-  main_canvas_keypressed(event);
-  
-  return FALSE;
+  return main_canvas_keypressed(event);
 }
 
 
@@ -362,3 +360,35 @@ on_nav_window_realize                  (GtkWidget       *widget,
   set_kay_accelerators();
 }
 
+
+void
+on_scroll_left_btn_clicked             (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  scroll_left_btn_clicked();
+}
+
+
+void
+on_scroll_right_btn_clicked            (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  scroll_right_btn_clicked();
+}
+
+
+void
+on_scroll_up_btn_clicked               (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  scroll_up_btn_clicked();
+}
+
+
+void
+on_scroll_down_btn_clicked             (GtkButton       *button,
+                                        gpointer         user_data)
+{
+  scroll_down_btn_clicked();
+}
+
