@@ -170,3 +170,19 @@ on_conf_accel_tview_cursor_changed     (GtkTreeView     *treeview,
 void
 on_nav_window_realize                  (GtkWidget       *widget,
                                         gpointer         user_data);
+
+void
+on_scroll_left_btn_clicked             (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_scroll_right_btn_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_scroll_up_btn_clicked               (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_scroll_down_btn_clicked             (GtkButton       *button,
+                                        gpointer         user_data);
