@@ -27,6 +27,14 @@ key_assignment key_asg[] = {
 			0,		GDK_p},
   {N_("Zoom 1:1"),	"zoom_orig_btn",
 			0,		GDK_1},
+  {N_("Scroll left"),	"scroll_left_btn",
+			0,		GDK_Left},
+  {N_("Scroll right"),	"scroll_right_btn",
+			0,		GDK_Right},
+  {N_("Scroll up"),	"scroll_up_btn",
+			0,		GDK_Up},
+  {N_("Scroll down"),	"scroll_down_btn",
+			0,		GDK_Down},
   {N_("Next page"),	"next_btn",
 			0,		GDK_Page_Down},
   {N_("Previous page"),	"back_btn",
@@ -38,9 +46,9 @@ key_assignment key_asg[] = {
   {N_("Open file"),	"open_btn",
 			0,		GDK_o},
   {N_("Quit cbrPager"),	"quit_btn",
-			0,		GDK_q}
+			0,		GDK_q},
+  {NULL}	// Sentinel - don't remove
 };
-#define nr_keys_assigned (sizeof(key_asg)/sizeof(key_assignment))
 
 preferences pref = {
   ""
@@ -85,7 +93,7 @@ save_config(void)
   sprintf(path, "%s/global/nav_hidden", prog_name);
   gnome_config_set_int(path, pref.nav_hidden);
 
-  for (ka = 0; ka < nr_keys_assigned; ka++) {
+  for (ka = 0; key_asg[ka].legend; ka++) {
     sprintf(path, "%s/accel/%s_mods", prog_name, key_asg[ka].widget);
     gnome_config_set_int(path, key_asg[ka].mods);
     sprintf(path, "%s/accel/%s_key", prog_name, key_asg[ka].widget);
@@ -140,7 +148,7 @@ load_config(void)
   if (pref.dirmode == DIRM_FIXED)		// fixed startup directory
     strncpy(pref.lastbook, pref.fixeddir, sizeof(pref.lastbook));
 
-  for (ka = 0; ka < nr_keys_assigned; ka++) {
+  for (ka = 0; key_asg[ka].legend; ka++) {
     sprintf(path, "%s/accel/%s_mods=%d", prog_name, key_asg[ka].widget,
 		key_asg[ka].mods);
     key_asg[ka].mods = gnome_config_get_int_with_default(path, &def);
@@ -306,7 +314,7 @@ parse_config(GtkWidget *ref)
   printf("parse: %d\n", pref.nav_hor);
 
   gtk_tree_model_get_iter_first(GTK_TREE_MODEL(accel_store), &iter);
-  for (ka = 0; ka < nr_keys_assigned; ka++) {
+  for (ka = 0; key_asg[ka].legend; ka++) {
     gtk_tree_model_get(GTK_TREE_MODEL(accel_store), &iter,
 	ACC_MODS, &mods,
 	ACC_ACCEL, &accel,
@@ -388,7 +396,7 @@ conf_accel_tview_realize(GtkTreeView *tview)
   gtk_tree_view_append_column(GTK_TREE_VIEW(accel_tview), col);
   gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(accel_tview), TRUE);
 
-  for (ka = 0; ka < nr_keys_assigned; ka++) {
+  for (ka = 0; key_asg[ka].legend; ka++) {
     gtk_list_store_append(accel_store, &iter);
     gtk_list_store_set(accel_store, &iter,
 	ACC_FUNCTION, _(key_asg[ka].legend),
@@ -407,7 +415,7 @@ set_kay_accelerators(void)
   accel_group = gtk_accel_group_new();
   gtk_window_add_accel_group(GTK_WINDOW(MainWindow), accel_group);
 
-  for (ka = 0; ka < nr_keys_assigned; ka++) {
+  for (ka = 0; key_asg[ka].legend; ka++) {
     w = lookup_widget(nav_window, key_asg[ka].widget);
     gtk_widget_add_accelerator(w, "clicked", accel_group,
 		key_asg[ka].accel,
