@@ -28,7 +28,10 @@
 
 enum {NAV_NW, NAV_NE, NAV_SE, NAV_SW};
 enum {DIRM_LAST, DIRM_FIXED};
-enum {RAR_FILE, ZIP_FILE};
+enum {	RAR_FILE,
+	ZIP_FILE,
+	SZ_FILE, 		/* Avuton 08/2008 */
+	ARCH_TYPES};		/* JC */
 
 enum {	ACC_FUNCTION,
 	ACC_MODS,
