@@ -311,7 +311,7 @@ start_show(void)
 
 
 void
-scroll_to(double where)
+v_scroll_to(double where)
 {
   GtkWidget *wdg;
   GtkAdjustment *adj;
@@ -327,6 +327,52 @@ scroll_to(double where)
 }
 
 
+void
+v_scroll(int up_down)
+{
+  GtkWidget *wdg;
+  GtkAdjustment *adj;
+  double range, newval;
+
+  wdg = lookup_widget(MainWindow, "main_scroller");
+  adj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(wdg));
+  if (debug)
+    printf("[vscroll] val: %.2f max: %.2f min: %.2f\n",
+	adj->value, adj->upper, adj->lower);
+
+  range = adj->upper - adj->page_size;
+  switch (up_down) {
+    case SCROLL_UP:
+      newval += range / 10.0;
+      if (newval > range) newval = range;
+      break;
+    case SCROLL_DOWN:
+      newval -= range / 10.0;
+      if (newval < 0) newval = 0.0;
+      break;
+  }
+  gtk_adjustment_set_value(GTK_ADJUSTMENT(adj), newval);
+  gtk_scrolled_window_set_vadjustment(GTK_SCROLLED_WINDOW(wdg), adj);
+}
+
+
+void
+h_scroll(int left_right)
+{
+  GtkWidget *wdg;
+  GtkAdjustment *adj;
+
+  wdg = lookup_widget(MainWindow, "main_scroller");
+  adj = gtk_scrolled_window_get_vadjustment(GTK_SCROLLED_WINDOW(wdg));
+  if (debug)
+    printf("[vscroll] val: %.2f max: %.2f min: %.2f\n",
+	adj->value, adj->upper, adj->lower);
+//  gtk_adjustment_set_value(GTK_ADJUSTMENT(adj),
+//		where*(adj->upper - adj->page_size));
+  gtk_scrolled_window_set_vadjustment(GTK_SCROLLED_WINDOW(wdg), adj);
+}
+
+
 void
 request_page(int nr, GdkPixbuf **pxm, double *w, double *h)
 {
@@ -493,8 +539,8 @@ next_page(int adv)
 
   show_page(page_nr);
   switch (pref.nextpage) {
-    case 0: scroll_to(0.0); break;
-    case 1: scroll_to(1.0); break;
+    case 0: v_scroll_to(0.0); break;
+    case 1: v_scroll_to(1.0); break;
   }
 }
 
@@ -513,8 +559,8 @@ previous_page(int prv)
 
   show_page(page_nr);
   switch (pref.prevpage) {
-    case 0: scroll_to(0.0); break;
-    case 1: scroll_to(1.0); break;
+    case 0: v_scroll_to(0.0); break;
+    case 1: v_scroll_to(1.0); break;
   }
 }
 
@@ -678,16 +724,19 @@ clean_up(void)
 }
 
 
-void
+gboolean
 main_canvas_keypressed(GdkEventKey *event)
 {
+printf("Key1: %04x\n", event->keyval);
 }
 
-void
+gboolean
 main_canvas_keypressed1(GdkEventKey *event)
 {
   GtkWidget *w;
   char *wdg;
+
+printf("Key: %04x\n", event->keyval);
   
   switch (event->keyval) {
     case GDK_space:
@@ -757,3 +806,29 @@ main_canvas_buttonpressed(GdkEventButton *event)
         break;
   }
 }
+
+
+void
+scroll_right_btn_clicked(void)
+{
+  h_scroll(SCROLL_RIGHT);
+}
+
+void
+scroll_left_btn_clicked(void)
+{
+  h_scroll(SCROLL_LEFT);
+}
+
+void
+scroll_up_btn_clicked(void)
+{
+  v_scroll(SCROLL_UP);
+}
+
+void
+scroll_down_btn_clicked(void)
+{
+  v_scroll(SCROLL_DOWN);
+}
+
