@@ -21,6 +21,12 @@
 
 #define FOLLOW_TIMER	150
 
+enum {	SCROLL_LEFT,
+	SCROLL_RIGHT,
+	SCROLL_UP,
+	SCROLL_DOWN
+};
+
 int		ok_dialog(char *ttl, char *msg);
 
 void		initial_setup(void);
@@ -36,7 +42,7 @@ void		file_list_tbtn_clicked(void);
 void		update_nav_position(void);
 void		install_timer(void);
 void		clean_up(void);
-void		main_canvas_keypressed(GdkEventKey *event);
+gboolean	main_canvas_keypressed(GdkEventKey *event);
 void		main_canvas_buttonpressed(GdkEventButton  *event);
 
 void		set_zoom_factor(double factor);
@@ -44,3 +50,8 @@ void		set_zoom_fit(void);
 void		set_zoom_width(void);
 void		fit_page(int w, int h);
 void		fit_width(int w);
+
+void		scroll_right_btn_clicked(void);
+void		scroll_left_btn_clicked(void);
+void		scroll_up_btn_clicked(void);
+void		scroll_down_btn_clicked(void);
\ No newline at end of file
